package org.gcube.portlets.user.td.widgetcommonevent.shared;

/**
 * 
 * @author "Giancarlo Panichi" 
 * <a href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a> 
 * 
 * Operations that can be launched from the grid menu
 */
public enum GridHeaderOperationId {
		COLUMNLABEL("4"),
		COLUMNADD("5"),
		COLUMNDELETE("6"),
		COLUMNTYPE("7"),
		COLUMNFILTER("8"),
		COLUMNBATCHREPLACE("9"),
		ANNOTATIONADD("10"),
		DUPLICATEDETECTION("11");		
		
		/**
		 * @param text
		 */
		private GridHeaderOperationId(final String id) {
			this.id = id;
		}

		private final String id;
		
		@Override
		public String toString() {
			return id;
		}
	
}
